@@ -19,15 +19,6 @@ except Exception as err:
     if not isinstance(err, netlinkerror_classes):
         raise
 
-try:
-    from libifstate.bpf import libbpf
-except OSError:
-    # ignore missing plugin
-    pass
-except AttributeError:
-    # ignore missing symbols (i.e. libbpf0)
-    pass
-
 try:
     from libifstate.xdp import XDP
 except ModuleNotFoundError:
@@ -46,7 +37,7 @@ import json
 import errno
 import logging
 
-__version__ = "1.6.0"
+__version__ = "1.6.1"
 
 
 class IfState():
